#!/usr/bin/python
######################################################################
## Filename:      encode.py
## Description:   Frontend to ease encoding of frame images into
##                h.264 video using avconv/ffmpeg
## Author:        David Dumas <david@dumas.io>
## Modified at:   Wed Nov 28 14:30:22 2012
##                
## Copyright (C) 2012 David Dumas
##                
## This program is free software distributed under the GNU General
## Public License (http://www.gnu.org/licenses/gpl.txt).
######################################################################

import argparse
import sys
import os
import os.path
import subprocess

parser = argparse.ArgumentParser(description='Encode movie as h.264')
parser.add_argument('-f','--framespec',help='Frames source',default='frame-%03d.png')
parser.add_argument('-n','--numframes',help='Maximum number of frames to encode, 0=all',type=int,default=0)
parser.add_argument('-o','--output',help='output filename; default is to generate a name')
parser.add_argument('-b','--bitrate',help='bitrate',default='8000k')
parser.add_argument('-r','--framerate',help='framerate',default='24')
parser.add_argument('--dry-run',action='store_true')

args = parser.parse_args()

if not args.output:
    base = os.path.basename(os.getcwd())
    args.output = base + '-r%s-%s' % (args.framerate,args.bitrate)
    if args.numframes > 0:
	args.output = args.output + '-n%d' % (args.numframes)
    args.output = args.output + '.mp4'

if args.numframes:
    args.numframestr = '-vframes %d' % args.numframes
else:
    args.numframestr = ''

cmdstr1='avconv -f image2 -r %(framerate)s -i \'%(framespec)s\' -c:v libx264 -r %(framerate)s -b %(bitrate)s -preset slower -pass 1 -f mp4 %(numframestr)s -y /dev/null' % vars(args)

cmdstr2='avconv -f image2 -r %(framerate)s -i \'%(framespec)s\' -c:v libx264 -r %(framerate)s -b %(bitrate)s -preset slower -pass 2 -f mp4 %(numframestr)s -y %(output)s' % vars(args)

if args.dry_run:
    print cmdstr1
    print cmdstr2
else:
    subprocess.call(cmdstr1,shell=True)
    subprocess.call(cmdstr2,shell=True)
